/**
 * Copyright (c) 2022, WSO2 LLC. (https://www.wso2.com). All Rights Reserved.
 *
 * This software is the property of WSO2 LLC. and its suppliers, if any.
 * Dissemination of any information or reproduction of any material contained
 * herein in any form is strictly forbidden, unless permitted by WSO2 expressly.
 * You may not alter or remove any copyright or other notice from copies of this content.
 */

/*
 * Logs constants.
 */
export class LogsConstants {

    /**
     * Log entries fetched per a single request.
     */
    public static readonly LOG_FETCH_COUNT: number = 20;

    /**
     * Height of a single log row in collapsed state.
     */
    public static readonly LOG_ROW_HEIGHT: number = 48;

    /**
     * Time zone related data array
     */
    public static readonly TIME_ZONE_DATA: Array<{key: number, text: string, value: string}> = [
        { key: 0, text: "(GMT+00:00) UTC", value: "GMT+0000 UTC"  },
        { key: 1, text: "(GMT+01:00) ECT", value: "GMT+0100 ECT"  },
        { key: 2, text: "(GMT+02:00) EET", value: "GMT+0200 EET"  },
        { key: 3, text: "(GMT+02:00) ART", value: "GMT+0200 ART"  },
        { key: 4, text: "(GMT+03:00) EAT", value: "GMT+0300 EAT"  },
        { key: 5, text: "(GMT+03:30) MET", value: "GMT+0330 MET"  },
        { key: 6, text: "(GMT+04:00) NET", value: "GMT+0400 NET"  },
        { key: 7, text: "(GMT+05:00) PLT", value: "GMT+0500 PLT"  },
        { key: 8, text: "(GMT+05:30) IST", value: "GMT+0530 IST"  },
        { key: 9, text: "(GMT+06:00) BST", value: "GMT+0600 BST"  },
        { key: 10, text: "(GMT+07:00) VST", value: "GMT+0700 VST"  },
        { key: 11, text: "(GMT+08:00) CTT", value: "GMT+0800 CTT"  },
        { key: 12, text: "(GMT+09:00) JST", value: "GMT+0900 JST"  },
        { key: 13, text: "(GMT+09:30) ACT", value: "GMT+0930 ACT"  },
        { key: 14, text: "(GMT+10:00) AET", value: "GMT+1000 AET"  },
        { key: 15, text: "(GMT+11:00) SST", value: "GMT+1100 SST"  },
        { key: 16, text: "(GMT+12:00) NST", value: "GMT+1200 NST"  },
        { key: 17, text: "(GMT-11:00) MIT", value: "GMT-1100 MIT"  },
        { key: 18, text: "(GMT-10:00) HST", value: "GMT-1000 HST"  },
        { key: 19, text: "(GMT-09:00) AST", value: "GMT-0900 AST"  },
        { key: 20, text: "(GMT-08:00) PST", value: "GMT-0800 PST"  },
        { key: 21, text: "(GMT-07:00) PNT", value: "GMT-0700 PNT"  },
        { key: 22, text: "(GMT-07:00) MST", value: "GMT-0700 MST"  },
        { key: 23, text: "(GMT-06:00) CST", value: "GMT-0600 CST"  },
        { key: 24, text: "(GMT-05:00) EST", value: "GMT-0500 EST"  },
        { key: 25, text: "(GMT-05:00) IET", value: "GMT-0500 IET"  },
        { key: 26, text: "(GMT-04:00) PRT", value: "GMT-0400 PRT"  },
        { key: 27, text: "(GMT-03:30) CNT", value: "GMT-0330 CNT"  },
        { key: 28, text: "(GMT-03:00) AGT", value: "GMT-0300 AGT"  },
        { key: 29, text: "(GMT-03:00) BET", value: "GMT-0300 BET"  },
        { key: 30, text: "(GMT-01:00) CAT", value: "GMT-0100 CAT"  }
    ];

    /**
     * Time range dropdown options
     */
    public static readonly TIMERANGE_DROPDOWN_OPTIONS: Array<{ key: number; text: string; value: number; }> = [
        // TODO: add i18n strings
        {
            key: 0,
            text: "Last 30 minutes",
            value: 0.5
        },
        {
            key: 1,
            text: "Last hour",
            value: 1
        },
        {
            key: 2,
            text: "Last 4 hours",
            value: 4
        },
        {
            key: 3,
            text: "Last 12 hours",
            value: 12
        },
        {
            key: 4,
            text: "Last 24 hours",
            value: 24
        },
        {
            key: 5,
            text: "Last 48 hours",
            value: 48
        },
        {
            key: 6,
            text: "Last 3 days",
            value: 72
        },
        {
            key: 7,
            text: "Last 7 days",
            value: 168
        }
    ];
}
